Introduction
============

Provides a `simplelayout`_ page for news.


Usage / Installation
====================

- See the `simplelayout.base <https://github.com/4teamwork/simplelayout.base>`_
  readme for details on installing simplelayout.

- Add ``simplelayout.types.news`` to your buildout configuration:

::

    [instance]
    eggs +=
        simplelayout.types.news

- Install the generic import profile.



Links
=====

- Simplelayout github project repository: https://github.com/4teamwork/simplelayout.base
- simplelayout.types.news github project repository: https://github.com/4teamwork/simplelayout.types.news
- Issue tracker: https://github.com/4teamwork/simplelayout.types.news/issues
- Package on pypi: http://pypi.python.org/pypi/simplelayout.types.news


Copyright
=========

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``simplelayout.types.news`` is licensed under GNU General Public License, version 2.

.. _simplelayout: https://github.com/4teamwork/simplelayout.base
